import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';

interface Article {
    id: string;
    title: string;
    content: string;
    author: string;
    publishedAt: string;
}

const ArticlePage: React.FC = () => {
    const { id } = useParams<{ id: string }>();
    const [article, setArticle] = useState<Article | null>(null);
    const [loading, setLoading] = useState<boolean>(true);
    const [error, setError] = useState<string | null>(null);

    useEffect(() => {
        fetch(`/api/article/${id}`)
                .then(response => response.json())
                .then(data => setArticle(data))
                .catch(_ => setError('Failed to fetch article'))
                .finally(() => setLoading(false));
    }, [id]);

    if (loading) {
        return <div>Loading...</div>;
    }

    if (error) {
        return <div>{error}</div>;
    }

    if (!article) {
        return <div>Article not found</div>;
    }

    return (
        <div>
            <img src="https://external-content.duckduckgo.com/iu/?u=https%3A%2F%2Fimages8.alphacoders.com%2F438%2F438396.jpg&f=1&nofb=1&ipt=14796576c139b58db62d2d2098392ef2fbaee77911040f7c0d98ab65a69c4644&ipo=images" alt="Article preview" style={{
                borderRadius: '8px',
                width: '100%',
                height: 'auto',
                marginBottom: '10px',
            }} />
            <h1>{article.title}</h1>
            <p>{article.content}</p>
            <p>By {article.author}</p>
            <p>Published on {new Date(article.publishedAt).toLocaleDateString()}</p>
        </div>
    );
};

export default ArticlePage;